powered by
Compute largest dose outcome minus average of other outcomes.
extract_max_vs_baseline(z, r)
the outcome r corresponding to the largest dose z minus the average of the outcomes r.
a vector of doses
a vector of outcomes
# dose vector dose <- c(0, 0.1, 0.4) # outcome vector outcome <- c(1, 1.1, 1.5) theta <- extract_max_vs_baseline(z = dose, r = outcome)
Run the code above in your browser using DataLab