powered by
Find the max ratio of probabilities between two permutations.
max_ratio_new(z, gamma)
the maximum ratio between the probability of two different permutations under the Rosenbaum model with doses z and unmeasured confounding level gamma.
vector of doses
The nonnegative sensitivity parameter; gamma = 0 means no unmeasured confounding.
# A vector of observed doses doses <- c(0, 0.1, 0.4, 0.8) ratio <- max_ratio_new(z = doses, gamma = 1)
Run the code above in your browser using DataLab