Learn R Programming

doseSens (version 1.0.0)

max_ratios_summary: Find the max ratio of probabilities between two permutations for each matched set.

Description

Find the max ratio of probabilities between two permutations for each matched set.

Usage

max_ratios_summary(Z, index, gamma)

Value

A vector of length equaling the number of unique indices that contains the maximum ratio between any two permutations for each of the matched sets.

Arguments

Z

A length N vector of observed doses.

index

A length N vector of indices indicating matched set membership.

gamma

The nonnegative sensitivity parameter; gamma = 0 means no unmeasured confounding.

Examples

Run this code
# A vector of observed doses
doses <- c(0, 0.1, 0.4, 0.8, 1)
matched_set <- c(1, 1, 1, 2, 2)
ratios <- max_ratios_summary(Z = doses, index = matched_set, gamma = 1)

Run the code above in your browser using DataLab