Learn R Programming

doseSens (version 1.0.0)

prob_bounds: A function to find the maximum and minimum probability of a permutation.

Description

A function to find the maximum and minimum probability of a permutation.

Usage

prob_bounds(z, gamma)

Value

a list containing the maximum and minimum probability of a permutation under the Rosenbaum model with doses z and unmeasured confounding level gamma.

Arguments

z

vector of doses

gamma

The nonnegative sensitivity parameter; gamma = 0 means no unmeasured confounding.

Examples

Run this code
# A vector of observed doses
doses <- c(0, 0.1, 0.4, 0.8)
bounds <- prob_bounds(z = doses, gamma = 1)

Run the code above in your browser using DataLab