Learn R Programming

doseSens (version 1.0.0)

var_est: A function for variance estimation

Description

A function for variance estimation

Usage

var_est(y, W, H_Q)

Value

a conservative estimate of the standard deviation of the test statistic.

Arguments

y

a vector of length I containing the value of test statistics from each matched set

W

weight vector of length I.

H_Q

hat matrix corresponding to a matrix Q with dimension I by L.

Examples

Run this code
test_stat <- c(1, 2, 1.5)
weight <- rep(1, 3)
Q <- matrix(1:9, nrow = 3, ncol = 2)
hat <- Q %*% solve(t(Q) %*% Q) %*% t(Q)

Run the code above in your browser using DataLab