powered by
A function to find the maximum and minimum probability of a permutation.
prob_bounds(z, gamma)
a list containing the maximum and minimum probability of a permutation under the Rosenbaum model with doses z and unmeasured confounding level gamma.
vector of doses
The nonnegative sensitivity parameter; gamma = 0 means no unmeasured confounding.
# A vector of observed doses doses <- c(0, 0.1, 0.4, 0.8) bounds <- prob_bounds(z = doses, gamma = 1)
Run the code above in your browser using DataLab